
  // Auto generated
  
    #ifndef QPRINTER_H_WRAPPER
    #define QPRINTER_H_WRAPPER

    // include header:
    //#include "header_h.h"
    
        #include "../RJSHelper.h"
      

    #include "RJSWrapperObj.h"
  
    #ifdef QT_PRINTSUPPORT_LIB
        #include <QPaintEngine>
      
        #include <QPrintEngine>
      
        #include <QPrinterInfo>
      
        #include <QPageSize>
      
    #include <QQmlEngine>
    
        #include "RJSType.h"
      
        #include <QPrinter>
      
    // static functions implementation in singleton wrapper:
    
    // wrapper class for QPrinter
    class QTJSAPI_EXPORT QPrinter_Wrapper : public RJSWrapperObj {

    
      Q_OBJECT
      QML_INTERFACE
    

    private:
      // disable copy constructor:
      QPrinter_Wrapper(const QPrinter_Wrapper&);

    public:
      // initialization of QPrinter:
      static void init(RJSApi& handler);

      
        static QPrinter* castToBase(void* vp, /*RJSType ID*/ int t) {
          
            // check if pointer points to derrived type:
            

          // hook for modules to cast from other types to base QPrinter:
          for (int i=0; i<basecasters_QPrinter.length(); i++) {
            RJSBasecaster_QPrinter* basecaster = basecasters_QPrinter[i];
            QPrinter* ret = basecaster->castToBase(t, vp);
            if (ret!=nullptr) {
              return ret;
            }
          }

          // object is a pointer to base class QPrinter:
          if (t==RJSType_QPrinter::getIdStatic()) {
            return (QPrinter*)vp;
          }

          qWarning() << "QPrinter_Wrapper::castToBase: type not found: " << RJSHelper::getTypeName(t);

          return nullptr;
          
        }

        static QPrinter* getWrappedBase(RJSWrapper* wrapper) {
          int t = wrapper->getWrappedType();
          void* vp = wrapper->getWrappedVoid();
          if (vp==nullptr) {
              //qWarning() << "getWrapped_QPrinter*: wrapper wraps NULL";
          }

          QPrinter* ret = castToBase(vp, t);
          if (ret==nullptr && vp!=nullptr) {
              qWarning() << "QPrinter*_Wrapper::getWrappedBase: extracted type " << t << "from wrapper is NULL";
          }
          return ret;
        }
      
        // enums:
        
  enum PdfVersion {
    PdfVersion_1_4 = QPrinter::PdfVersion_1_4,
PdfVersion_A1b = QPrinter::PdfVersion_A1b,
PdfVersion_1_6 = QPrinter::PdfVersion_1_6,

  };
  Q_ENUM(PdfVersion)

  enum PrinterMode {
    ScreenResolution = QPrinter::ScreenResolution,
PrinterResolution = QPrinter::PrinterResolution,
HighResolution = QPrinter::HighResolution,

  };
  Q_ENUM(PrinterMode)

  enum PageOrder {
    FirstPageFirst = QPrinter::FirstPageFirst,
LastPageFirst = QPrinter::LastPageFirst,

  };
  Q_ENUM(PageOrder)

  enum ColorMode {
    GrayScale = QPrinter::GrayScale,
Color = QPrinter::Color,

  };
  Q_ENUM(ColorMode)

  enum PaperSource {
    OnlyOne = QPrinter::OnlyOne,
Lower = QPrinter::Lower,
Middle = QPrinter::Middle,
Manual = QPrinter::Manual,
Envelope = QPrinter::Envelope,
EnvelopeManual = QPrinter::EnvelopeManual,
Auto = QPrinter::Auto,
Tractor = QPrinter::Tractor,
SmallFormat = QPrinter::SmallFormat,
LargeFormat = QPrinter::LargeFormat,
LargeCapacity = QPrinter::LargeCapacity,
Cassette = QPrinter::Cassette,
FormSource = QPrinter::FormSource,
MaxPageSource = QPrinter::MaxPageSource,
CustomSource = QPrinter::CustomSource,
LastPaperSource = QPrinter::LastPaperSource,
Upper = QPrinter::Upper,

  };
  Q_ENUM(PaperSource)

  enum PrinterState {
    Idle = QPrinter::Idle,
Active = QPrinter::Active,
Aborted = QPrinter::Aborted,
Error = QPrinter::Error,

  };
  Q_ENUM(PrinterState)

  enum OutputFormat {
    NativeFormat = QPrinter::NativeFormat,
PdfFormat = QPrinter::PdfFormat,

  };
  Q_ENUM(OutputFormat)

  enum PrintRange {
    AllPages = QPrinter::AllPages,
Selection = QPrinter::Selection,
PageRange = QPrinter::PageRange,
CurrentPage = QPrinter::CurrentPage,

  };
  Q_ENUM(PrintRange)

  enum Unit {
    Millimeter = QPrinter::Millimeter,
Point = QPrinter::Point,
Inch = QPrinter::Inch,
Pica = QPrinter::Pica,
Didot = QPrinter::Didot,
Cicero = QPrinter::Cicero,
DevicePixel = QPrinter::DevicePixel,

  };
  Q_ENUM(Unit)

  enum DuplexMode {
    DuplexNone = QPrinter::DuplexNone,
DuplexAuto = QPrinter::DuplexAuto,
DuplexLongSide = QPrinter::DuplexLongSide,
DuplexShortSide = QPrinter::DuplexShortSide,

  };
  Q_ENUM(DuplexMode)

    /*
    // special constructor used as prototype:
    
          Q_INVOKABLE 
          QPrinter_Wrapper(QJSEngine* e);
        
    */

    
      // special constructor to wrap existing object:
      
            //Q_INVOKABLE 
            QPrinter_Wrapper(RJSApi& h, QPrinter* o, bool wrappedCreated);
          

      // destructor:
      
          virtual ~QPrinter_Wrapper();
        
    // initialization of signal forwarding
    
        void initConnections();
      

  // constructors:
  
    // Class: QPrinter
    // Function: 
    // Source: 
    // Static: false
    // Parameters: 2
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              QPrinter_Wrapper
                
              (

                
                  // RJSApi:
                  QObject* h
                  
                  ,
                  
  const QJSValue& 
  a1
      = QJSValue()
    , 
  const QJSValue& 
  a2
      = QJSValue()
    
              )
              
              ;
            
#if defined(Q_OS_WIN)||defined(Q_CLANG_QDOC)

#endif


    // non-static functions:
    
    // Class: QPrinter
    // Function: paintingActive
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  paintingActive
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: width
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  width
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: height
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  height
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: widthMM
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  widthMM
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: heightMM
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  heightMM
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: logicalDpiX
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  logicalDpiX
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: logicalDpiY
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  logicalDpiY
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: physicalDpiX
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  physicalDpiX
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: physicalDpiY
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  physicalDpiY
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: devicePixelRatio
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  devicePixelRatio
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: devicePixelRatioF
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  devicePixelRatioF
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: colorCount
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  colorCount
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: depth
    // Source: QPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  depth
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setPageLayout
    // Source: QPagedPaintDevice
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPageLayout
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: setPageSize
    // Source: QPagedPaintDevice
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPageSize
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: setPageOrientation
    // Source: QPagedPaintDevice
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPageOrientation
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: setPageMargins
    // Source: QPagedPaintDevice
    // Static: false
    // Parameters: 2
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPageMargins
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    , 
  const QJSValue& 
  a2
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: pageLayout
    // Source: QPagedPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  pageLayout
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setPageRanges
    // Source: QPagedPaintDevice
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPageRanges
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: pageRanges
    // Source: QPagedPaintDevice
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  pageRanges
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: devType
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  devType
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setOutputFormat
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setOutputFormat
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: outputFormat
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  outputFormat
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setPdfVersion
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPdfVersion
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: pdfVersion
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  pdfVersion
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setPrinterName
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPrinterName
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: printerName
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  printerName
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: isValid
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  isValid
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setOutputFileName
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setOutputFileName
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: outputFileName
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  outputFileName
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setPrintProgram
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPrintProgram
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: printProgram
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  printProgram
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setDocName
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setDocName
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: docName
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  docName
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setCreator
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setCreator
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: creator
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  creator
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setPageOrder
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPageOrder
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: pageOrder
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  pageOrder
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setResolution
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setResolution
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: resolution
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  resolution
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setColorMode
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setColorMode
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: colorMode
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  colorMode
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setCollateCopies
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setCollateCopies
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: collateCopies
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  collateCopies
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setFullPage
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setFullPage
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: fullPage
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  fullPage
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setCopyCount
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setCopyCount
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: copyCount
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  copyCount
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: supportsMultipleCopies
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  supportsMultipleCopies
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setPaperSource
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPaperSource
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: paperSource
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  paperSource
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setDuplex
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setDuplex
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: duplex
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  duplex
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: supportedResolutions
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  supportedResolutions
              (

                
              )
              
                const
              
              ;
            
#if defined(Q_OS_WIN)||defined(Q_CLANG_QDOC)

    // Class: QPrinter
    // Function: supportedPaperSources
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  supportedPaperSources
              (

                
              )
              
                const
              
              ;
            
#endif

    // Class: QPrinter
    // Function: setFontEmbeddingEnabled
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setFontEmbeddingEnabled
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: fontEmbeddingEnabled
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  fontEmbeddingEnabled
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: paperRect
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  paperRect
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: pageRect
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  pageRect
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: printerSelectionOption
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  printerSelectionOption
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setPrinterSelectionOption
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPrinterSelectionOption
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: newPage
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  newPage
              (

                
              )
              
              ;
            
    // Class: QPrinter
    // Function: abort
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  abort
              (

                
              )
              
              ;
            
    // Class: QPrinter
    // Function: printerState
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  printerState
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: paintEngine
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  paintEngine
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setFromTo
    // Source: 
    // Static: false
    // Parameters: 2
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setFromTo
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    , 
  const QJSValue& 
  a2
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: fromPage
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  fromPage
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: toPage
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  toPage
              (

                
              )
              
                const
              
              ;
            
    // Class: QPrinter
    // Function: setPrintRange
    // Source: 
    // Static: false
    // Parameters: 1
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  setPrintRange
              (

                
  const QJSValue& 
  a1
      = QJSValue()
    
              )
              
              ;
            
    // Class: QPrinter
    // Function: printRange
    // Source: 
    // Static: false
    // Parameters: 0
    // preceding Parameters: -1

              public:
              Q_INVOKABLE 
              
                  QJSValue 
                  printRange
              (

                
              )
              
                const
              
              ;
            
          // destroy function for non-copyable objects:
          Q_INVOKABLE void destr() {
            
              if (wrapped!=nullptr) {
                
                    delete wrapped;
                  
                wrapped = nullptr;
              }
            
          }
        

        //public:
        // set engine:
        //Q_INVOKABLE void setHandler(RJSApi* h) {
        //  RJSWrapperObj::setHandler(h);
        //}
      

  // member functions for static properties, forward to static function
  


  // protected overwritten functions / events and their public invokable counterparts:
  
        public:

        // get type of wrapped object:
        Q_INVOKABLE
        virtual /*RJSType ID*/ int getWrappedType() const {
          return RJSType_QPrinter::getIdStatic();
        }

        // return true if wrapped object is owned by C++ (not deleted):
        Q_INVOKABLE
        virtual bool isCppOwnership() const {
          
              return true;
            
        }

        // get wrapped object:
        QPrinter* getWrapped() {
          
            if (wrapped!=nullptr) {
              return wrapped;
            }
          
          return nullptr;
        }

        // get wrapped object (const):
        QPrinter* getWrapped() const {
          
            if (wrapped!=nullptr) {
              return wrapped;
            }
          
          return nullptr;
        }

        // get wrapped object as void*:
        virtual void* getWrappedVoid() {
          
            if (wrapped!=nullptr) {
              return wrapped;
            }
          
          return nullptr;
        }

        

        bool hasWrapped() const {
          
            return wrapped!=nullptr 
          
          ;
        }

        Q_INVOKABLE
        bool isNullWrapper() const {
          return !hasWrapped();
        }

        Q_INVOKABLE
        unsigned long long int getAddress() const {
          
            if (wrapped!=nullptr) {
              return (unsigned long long int)wrapped;
            }
          
          return (unsigned long long int)0;
        }

        

        //public slots:
          //void slotDestroyed(QObject* obj) {
          //  qDebug() << "destroying QObject:" << (long int)obj;
          //}

        

        private:

        
          // wrapped object:
          QPrinter* wrapped;
        

        bool wrappedCreated;
      
      private:
        // list of registered base casters for this wrapper class:
        static QList<RJSBasecaster_QPrinter*> basecasters_QPrinter;

      public:
        static void registerBasecaster_QPrinter(RJSBasecaster_QPrinter* bc) {
          basecasters_QPrinter.append(bc);
        }
      
    };

    Q_DECLARE_METATYPE(QPrinter_Wrapper*)

    Q_DECLARE_INTERFACE(QPrinter_Wrapper, "org.qcad.QPrinter_Wrapper")

  
    #endif
  
  #endif
  
